Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
lice2/__init__.py | 3 | 0 | 0 | 100%
lice2/api/__init__.py | 2 | 0 | 0 | 100%
lice2/api/api.py | 43 | 0 | 0 | 100%
lice2/api/exceptions.py | 18 | 0 | 0 | 100%
lice2/config.py | 19 | 0 | 0 | 100%
lice2/constants.py | 15 | 0 | 0 | 100%
lice2/core.py | 46 | 0 | 1 | 100%
lice2/helpers.py | 184 | 0 | 0 | 100%
lice2/templates/__init__.py | 0 | 0 | 0 | 100%
Total | 330 | 0 | 1 | 100%

No items found using the specified filter.